@@ -22,10 +22,13 @@ class DummyKnowledgeParser(KnowledgeParserBase):
         bar.max = 1
         bar.start()
         bar.next()
-        yield Term(identifier=options.foo, preferredForm=options.foo)
+        yield Term(identifier=options.foo, preferredForm=options.foo, properties={ 'altForms' : [ options.foo.upper() ] })
         bar.finish()
 
     @classmethod
-    def get_schema(cls) -> Type[BaseModel]:
+    def get_schema(cls) -> KnowledgeParserOptions:
         return DummyOptions
 
+    @classmethod
+    def get_model(cls) -> Type[BaseModel]:
+        return DummyOptionsModel
